@@ -1,10 +1,11 @@
 import json
 import os
 import random
+import sys
 
 
 def real_random_address() -> dict:
-    package_directory = os.path.dirname(os.path.realpath(__file__))
+    package_directory = os.path.dirname(sys.modules[__name__].__file__)
     source_filename_path = os.path.join(package_directory,
                                         'addresses-us-all.json')
     source_filename = open(source_filename_path)
